import router from "@/router";
import NProgress from "@/utils/nprogress";
import { useDictionaryStore } from "@/store/modules/dictionary";

export function setupPermission() {
  // 白名单路由
  const whiteList: string[] = ["client-traceability"]; //由于包含动态路由，这里面存储的是路由的name而不是path

  router.beforeEach(async (to, from, next) => {
    NProgress.start();
    const hasToken = localStorage.getItem("token");
    if (hasToken) {
      if (to.path === "/login") {
        // 如果已登录，跳转首页
        next({ path: "/" });
        NProgress.done();
      } else {
        const dictStore = useDictionaryStore();
        dictStore.checkAllData();
        next();
        NProgress.done();
      }
    } else {
      // 未登录可以访问白名单页面

      if (whiteList.indexOf(to.name as string) !== -1) {
        const dictStore = useDictionaryStore();
        dictStore.checkAllData();
        next();
      } else {
        if (to.path === "/login") {
          next();
        } else {
          next(`/login`);
        }
        NProgress.done();
      }
    }
  });

  router.afterEach(() => {
    NProgress.done();
  });
}
